provider

package
v0.0.0-...-10bec2a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 4, 2022 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provider

type Provider interface {
	Name() string
	Support(string, string) bool
	Bump(string, string, string) (string, string, error)
	Hashes() bool
}

Provider represents a source from which a package and/or a tarball can be obtained

func All

func All() (readyProviders []Provider)

All return the array of usable providers

func For

func For(url, version string) (Provider, error)

For returns the corresponding Provider for the given url, an error otherwise

Directories

Path Synopsis

Jump to